@@ -1,10 +1,10 @@
 /* Fault handler information.  MacOSX/Darwin7/PowerPC version.
-   Copyright (C) 2002-2004  Bruno Haible <bruno@clisp.org>
+   Copyright (C) 2002-2004, 2007  Bruno Haible <bruno@clisp.org>
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,8 +12,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 #include "fault-macosdarwin7-powerpc.c"
 
@@ -21,4 +20,8 @@
 #define SIGSEGV_FAULT_ADDRESS  (unsigned long) get_fault_addr (sip, ucp)
 #define SIGSEGV_FAULT_CONTEXT  ucp
 #define SIGSEGV_FAULT_ADDRESS_FROM_SIGINFO
+#if __DARWIN_UNIX03
+#define SIGSEGV_FAULT_STACKPOINTER  ucp->uc_mcontext->ss.__r1
+#else
 #define SIGSEGV_FAULT_STACKPOINTER  ucp->uc_mcontext->ss.r1
+#endif
